==> haskell-vector-hashtables-0.1.2.1-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-hashtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-hashtables
version:              0.1.2.1
visibility:           public
id:                   vector-hashtables-0.1.2.1-B1WzDzGvUhx4qlTa5AOMnA
key:                  vector-hashtables-0.1.2.1-B1WzDzGvUhx4qlTa5AOMnA
license:              BSD-3-Clause
copyright:            2016-2024 klapaucius, swamp_agr
maintainer:           klapaucius, swamp_agr, ArtemPelenitsyn
author:               klapaucius
homepage:             https://github.com/klapaucius/vector-hashtables#readme
synopsis:             Efficient vector-based mutable hashtables implementation.
description:
    This package provides efficient vector-based hashtable implementation similar to .NET Generic Dictionary implementation (at the time of 2015).

    See "Data.Vector.Hashtables" for documentation.

category:             Data
abi:                  e2dbebedd2d8744e13e62d964bf77aa5
exposed:              True
exposed-modules:
    Data.Primitive.PrimArray.Utils Data.Vector.Hashtables
    Data.Vector.Hashtables.Internal
    Data.Vector.Hashtables.Internal.Mask

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-hashtables-0.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-hashtables-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-hashtables-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-hashtables
hs-libraries:         HSvector-hashtables-0.1.2.1-B1WzDzGvUhx4qlTa5AOMnA
depends:
    base-4.17.2.1 hashable-1.4.4.0-5SoCNaysfySGuPwu0aljBu
    primitive-0.9.1.0-3MsYNTRfRHtDQ9eN2n6le5
    vector-0.13.2.0-52P7Ozt5w3I6hi4WvheJB9

haddock-interfaces:
    /usr/share/doc/haskell-vector-hashtables/html/vector-hashtables.haddock

haddock-html:         /usr/share/doc/haskell-vector-hashtables/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-hashtables-0.1.2.1-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-hashtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-hashtables
version:              0.1.2.1
visibility:           public
id:                   vector-hashtables-0.1.2.1-7c7D0oMhFMTKqgRXPpwcRe
key:                  vector-hashtables-0.1.2.1-7c7D0oMhFMTKqgRXPpwcRe
license:              BSD-3-Clause
copyright:            2016-2024 klapaucius, swamp_agr
maintainer:           klapaucius, swamp_agr, ArtemPelenitsyn
author:               klapaucius
homepage:             https://github.com/klapaucius/vector-hashtables#readme
synopsis:             Efficient vector-based mutable hashtables implementation.
description:
    This package provides efficient vector-based hashtable implementation similar to .NET Generic Dictionary implementation (at the time of 2015).

    See "Data.Vector.Hashtables" for documentation.

category:             Data
abi:                  e67d06f40871fdb196c0101e4513a93e
exposed:              True
exposed-modules:
    Data.Primitive.PrimArray.Utils Data.Vector.Hashtables
    Data.Vector.Hashtables.Internal
    Data.Vector.Hashtables.Internal.Mask

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-hashtables-0.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-hashtables-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-hashtables-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-hashtables
hs-libraries:         HSvector-hashtables-0.1.2.1-7c7D0oMhFMTKqgRXPpwcRe
depends:
    base-4.17.2.1 hashable-1.4.4.0-2lvxXC6j7O5I2GR31C0SqX
    primitive-0.9.1.0-3qHntBOAe4Y4he61Fs3OAc
    vector-0.13.2.0-K0fBmK5qd7y3388236ZS0A

haddock-interfaces:
    /usr/share/doc/haskell-vector-hashtables/html/vector-hashtables.haddock

haddock-html:         /usr/share/doc/haskell-vector-hashtables/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
